@@ -1,8 +1,24 @@
-"""Termostat device types."""
-import logging
+"""Thermostat device types."""
 from datetime import datetime
-from ..aldb import ALDB
+import logging
+
+from ..aldb.aldb import ALDB
 from ..aldb.aldb_battery import ALDBBattery
+from ..config import (
+    BACKLIGHT,
+    BUTTON_LOCK_ON,
+    CELSIUS,
+    CHANGE_DELAY,
+    HUMIDITY_OFFSET,
+    KEY_BEEP_ON,
+    LED_ON,
+    OPERATING_FLAGS,
+    PROGRAM_LOCK_ON,
+    TEMP_OFFSET,
+    TIME_24_HOUR_FORMAT,
+)
+from ..config.op_flag_property import OpFlagProperty
+from ..constants import PropertyType, ResponseStatus, ThermostatMode
 from ..default_link import DefaultLink
 from ..groups import (
     COOL_SET_POINT,
@@ -12,55 +28,34 @@ from ..groups import (
     HEAT_SET_POINT,
     HEATING,
     HUMIDIFYING,
+    HUMIDITY,
     HUMIDITY_HIGH,
     HUMIDITY_LOW,
     SYSTEM_MODE,
     TEMPERATURE,
-    HUMIDITY,
 )
-from ..extended_property import (
-    BACKLIGHT,
-    CHANGE_DELAY,
-    TEMP_OFFSET,
-    HUMIDITY_OFFSET,
-)
-from ..groups.thermostat import FanMode, Humidity, SystemMode, Temperature, SetPoint
 from ..groups.on_off import OnOff
-from ..managers.on_level_manager import OnLevelManager
-from ..handlers.from_device.thermostat_status_response import (
-    ThermostatStatusResponseHandler,
-)
-from ..handlers.from_device.thermostat_set_point_response import (
-    ThermostatSetPointResponseHandler,
-)
+from ..groups.thermostat import FanMode, Humidity, SetPoint, SystemMode, Temperature
 from ..handlers.from_device.thermostat_cool_set_point import (
     ThermostatCoolSetPointHandler,
 )
 from ..handlers.from_device.thermostat_heat_set_point import (
     ThermostatHeatSetPointHandler,
 )
-from ..handlers.from_device.thermostat_mode import ThermostatModeHandler
 from ..handlers.from_device.thermostat_humidity import ThermostatHumidityHandler
+from ..handlers.from_device.thermostat_mode import ThermostatModeHandler
 from ..handlers.from_device.thermostat_temperature import ThermostatTemperatureHandler
+from ..handlers.to_device.extended_set import ExtendedSetCommand
 from ..handlers.to_device.thermostat_cool_set_point import ThermostatCoolSetPointCommand
 from ..handlers.to_device.thermostat_heat_set_point import ThermostatHeatSetPointCommand
 from ..handlers.to_device.thermostat_mode import ThermostatModeCommand
-from ..handlers.to_device.extended_set import ExtendedSetCommand
-from ..handlers.to_device.extended_set_2 import ExtendedSet2Command
+from ..managers.link_manager.default_links import async_add_default_links
+from ..managers.on_level_manager import OnLevelManager
 from ..managers.thermostat_status_manager import GetThermostatStatus
-from ..operating_flag import (
-    BUTTON_LOCK_ON,
-    CELSIUS,
-    KEY_BEEP_ON,
-    LED_ON,
-    PROGRAM_LOCK_ON,
-    TIME_24_HOUR_FORMAT,
-)
-from .commands import STATUS_COMMAND
-from .device_base import Device
+from ..utils import multiple_status, to_fahrenheit
 from .battery_base import BatteryDeviceBase
-from ..utils import multiple_status, to_fahrenheit, set_bit
-from ..constants import ResponseStatus
+from .device_base import Device
+from .device_commands import STATUS_COMMAND
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -113,9 +108,11 @@ class ClimateControl_Thermostat(Device):
         return await self._handlers["heat_set_point_command"].async_send(temperature)
 
     async def async_set_humidity_high_set_point(self, humidity):
-        """Set the humdity high set point."""
+        """Set the humidity high set point."""
         humidity = min(humidity, 99)
-        cmd_status = await self._handlers["humidity_high_command"].async_send(humidity)
+        cmd_status = await self._handlers["humidity_high_command"].async_send(
+            data3=humidity
+        )
         if cmd_status == ResponseStatus.SUCCESS:
             self._groups[GRP_HUMID_HI_SP].value = humidity
         return cmd_status
@@ -123,18 +120,20 @@ class ClimateControl_Thermostat(Device):
     async def async_set_humidity_low_set_point(self, humidity):
         """Set the humidity low set point."""
         humidity = max(humidity, 1)
-        cmd_status = await self._handlers["humidity_low_command"].async_send(humidity)
+        cmd_status = await self._handlers["humidity_low_command"].async_send(
+            data3=humidity
+        )
         if cmd_status == ResponseStatus.SUCCESS:
             self._groups[GRP_HUMID_LO_SP].value = humidity
         return cmd_status
 
-    async def async_set_mode(self, mode):
-        """Set the thermastat mode."""
-        return await self._handlers["mode_command"].async_send(mode)
+    async def async_set_mode(self, thermostat_mode):
+        """Set the thermostat mode."""
+        return await self._handlers["mode_command"].async_send(thermostat_mode)
 
     async def async_set_master(self, master):
-        """Set the thermastat master mode."""
-        return await self._handlers["set_master"].async_send(master)
+        """Set the thermostat master mode."""
+        return await self._handlers["set_master"].async_send(data3=master)
 
     async def async_set_notify_changes(self):
         """Set the thermostat to notify of changes."""
@@ -144,49 +143,47 @@ class ClimateControl_Thermostat(Device):
         """Set the thermostat day of the week and time."""
         curr_time = datetime.now()
         day = 0 if curr_time.weekday() == 6 else curr_time.weekday() + 1
-        set_time_command = ExtendedSet2Command(self._address, 0x02, day)
+        set_time_command = ExtendedSetCommand(
+            self._address, cmd2=0x02, data1=0x02, data2=day
+        )
         return await set_time_command.async_send(
             data3=curr_time.hour, data4=curr_time.minute, data5=curr_time.second
         )
 
     async def async_add_default_links(self):
-        """Add the default links betweent he modem and the device."""
+        """Add the default links between the modem and the device."""
         result_links = await super().async_add_default_links()
         result_notify = await self.async_set_notify_changes()
         return multiple_status(result_links, result_notify)
 
-    async def async_write_op_flags(self):
-        """Write the operating flags to the device."""
-        flags = 0x00
-        for flag_name in self._ext_property_manager.flag_info:
-            flag_info = self._ext_property_manager.flag_info[flag_name]
-            if flag_info.data_field == OP_FLAG_POS:
-                flag = self.properties[flag_name]
-                value = flag.new_value if flag.is_dirty else flag.value
-                flags = set_bit(flags, flag_info.bit, bool(value))
-        result = await self._handlers["op_flag_write"].async_send(data4=flags)
-        if result == ResponseStatus.SUCCESS:
-            for flag_name in self._ext_property_manager.flag_info:
-                flag_info = self._ext_property_manager.flag_info[flag_name]
-                if flag_info.data_field == OP_FLAG_POS:
-                    flag = self.properties[flag_name]
-                    if flag.is_dirty:
-                        flag.load(flag.new_value)
-        return result
-
-    def _register_operating_flags(self):
+    def _register_op_flags_and_props(self):
         """Register thermostat operating flags."""
-        self._add_property(PROGRAM_LOCK_ON, OP_FLAG_POS, None, 0, 0)
-        self._add_property(KEY_BEEP_ON, OP_FLAG_POS, None, 0, 1)
-        self._add_property(BUTTON_LOCK_ON, OP_FLAG_POS, None, 0, 2)
-        self._add_property(CELSIUS, OP_FLAG_POS, None, 0, 3)
-        self._add_property(TIME_24_HOUR_FORMAT, OP_FLAG_POS, None, 0, 4)
-        self._add_property(LED_ON, OP_FLAG_POS, None, 0, 6)
+        self._add_property(TEMP_OFFSET, 6, 2, 0, prop_type=PropertyType.ADVANCED)
+        self._add_property(HUMIDITY_OFFSET, 7, 3, 0, prop_type=PropertyType.ADVANCED)
+        self._add_property(BACKLIGHT, 10, 5, 0)
+        self._add_property(CHANGE_DELAY, 11, 6, 0)
+        self._add_property(OPERATING_FLAGS, 13, 4, 0, prop_type=PropertyType.ADVANCED)
 
-        self._add_property(TEMP_OFFSET, 5, 2, 0)
-        self._add_property(HUMIDITY_OFFSET, 6, 3, 0)
-        self._add_property(BACKLIGHT, 9, 5, 0)
-        self._add_property(CHANGE_DELAY, 10, 6, 0)
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        op_flags = self._properties[OPERATING_FLAGS]
+        self._config[PROGRAM_LOCK_ON] = OpFlagProperty(
+            self._address, PROGRAM_LOCK_ON, op_flags, 0
+        )
+        self._config[KEY_BEEP_ON] = OpFlagProperty(
+            self._address, KEY_BEEP_ON, op_flags, 1
+        )
+        self._config[BUTTON_LOCK_ON] = OpFlagProperty(
+            self._address, BUTTON_LOCK_ON, op_flags, 2
+        )
+        self._config[CELSIUS] = OpFlagProperty(self._address, CELSIUS, op_flags, 3)
+        self._config[TIME_24_HOUR_FORMAT] = OpFlagProperty(
+            self._address, TIME_24_HOUR_FORMAT, op_flags, 4
+        )
+        self._config[LED_ON] = OpFlagProperty(self._address, LED_ON, op_flags, 6)
+
+        self._config[CELSIUS].subscribe(self._temp_format_first_set)
 
     def _register_groups(self):
         """Register the thermostat groups."""
@@ -210,10 +207,16 @@ class ClimateControl_Thermostat(Device):
             FAN_MODE, self._address, group=GRP_FAN_MODE, default=4
         )
         self._groups[GRP_COOL_SP] = SetPoint(
-            COOL_SET_POINT, self._address, group=GRP_COOL_SP, default=65,
+            COOL_SET_POINT,
+            self._address,
+            group=GRP_COOL_SP,
+            default=65,
         )
         self._groups[GRP_HEAT_SP] = SetPoint(
-            HEAT_SET_POINT, self._address, group=GRP_HEAT_SP, default=95,
+            HEAT_SET_POINT,
+            self._address,
+            group=GRP_HEAT_SP,
+            default=95,
         )
         self._groups[GRP_HUMID_HI_SP] = Humidity(
             HUMIDITY_HIGH, self._address, group=GRP_HUMID_HI_SP, default=0
@@ -235,12 +238,6 @@ class ClimateControl_Thermostat(Device):
         )
 
         self._managers[STATUS_COMMAND] = GetThermostatStatus(self._address)
-        self._handlers["status_response"] = ThermostatStatusResponseHandler(
-            self._address
-        )
-        self._handlers["set_point_response"] = ThermostatSetPointResponseHandler(
-            self._address
-        )
         self._handlers["cool_set_point_handler"] = ThermostatCoolSetPointHandler(
             self._address
         )
@@ -285,8 +282,8 @@ class ClimateControl_Thermostat(Device):
             self._groups[GRP_HUMID_LO_ON].set_value
         )
 
-        self._handlers["status_response"].subscribe(self._status_received)
-        self._handlers["set_point_response"].subscribe(self._set_point_received)
+        self._managers[STATUS_COMMAND].subscribe_status(self._status_received)
+        self._managers[STATUS_COMMAND].subscribe_set_point(self._set_point_received)
         self._handlers["cool_set_point_handler"].subscribe(
             self._groups[GRP_COOL_SP].set_value
         )
@@ -296,7 +293,10 @@ class ClimateControl_Thermostat(Device):
         self._handlers["humidity_handler"].subscribe(self._groups[GRP_HUMID].set_value)
         self._handlers["temperature_handler"].subscribe(self._temp_received)
         self._handlers["mode_handler"].subscribe(self._mode_received)
-        self._properties[CELSIUS].subscribe(self._temp_format_first_set)
+
+        self._handlers["cool_set_point_command"].subscribe(self._cool_set_point_set)
+        self._handlers["heat_set_point_command"].subscribe(self._heat_set_point_set)
+        self._handlers["mode_command"].subscribe(self._mode_set)
 
     def _register_default_links(self):
         """Register default links."""
@@ -380,14 +380,13 @@ class ClimateControl_Thermostat(Device):
         self._groups[GRP_FAN_MODE].set_value(fan_mode)
         self._groups[GRP_COOL_SP].set_value(cool_set_point)
         self._groups[GRP_HEAT_SP].set_value(heat_set_point)
-        if not self._properties[CELSIUS].value:
+        if not self._config[CELSIUS].value:
             temperature = to_fahrenheit(temperature)
         self._groups[GRP_TEMP].set_value(temperature)
         self._groups[GRP_HUMID].set_value(humidity)
 
     def _set_point_received(
         self,
-        stage_1_on_minutes,
         humidity_high,
         humidity_low,
         firmwire,
@@ -406,13 +405,20 @@ class ClimateControl_Thermostat(Device):
         self._groups[GRP_SYS_MODE].set_value(system_mode)
         self._groups[GRP_FAN_MODE].set_value(fan_mode)
 
+    def _mode_set(self, thermostat_mode: ThermostatMode):
+        """Update the thermostat mode from a set mode command."""
+        if thermostat_mode in [ThermostatMode.FAN_ALWAYS_ON, ThermostatMode.FAN_AUTO]:
+            self._groups[GRP_FAN_MODE].set_value(thermostat_mode)
+        else:
+            self._groups[GRP_SYS_MODE].set_value(thermostat_mode)
+
     def _temp_received(self, degrees):
         """Receive temperature status update and convert to celsius if needed."""
         self._groups[GRP_TEMP].value = degrees
 
-    def _temp_format_changed(self, name, value):
-        """Recieve notification that the thermostat has changed to/from C/F."""
-        self.status()
+    async def _async_temp_format_changed(self, name, value):
+        """Receive notification that the thermostat has changed to/from C/F."""
+        await self.async_status()
 
     def _temp_format_first_set(self, name, value):
         """Set up the trigger for a temperature format change.
@@ -421,8 +427,16 @@ class ClimateControl_Thermostat(Device):
         the format changes later, we need to get the status update to change the
         measurements from F to C or vise versa.
         """
-        self._properties[CELSIUS].unsubscribe(self._temp_format_first_set)
-        self._properties[CELSIUS].unsubscribe(self._temp_format_changed)
+        self._config[CELSIUS].unsubscribe(self._temp_format_first_set)
+        self._config[CELSIUS].subscribe(self._async_temp_format_changed)
+
+    def _cool_set_point_set(self, degrees, zone, deadband):
+        """Cool set point changed."""
+        self._groups[GRP_COOL_SP].set_value(degrees)
+
+    def _heat_set_point_set(self, degrees, zone, deadband):
+        """Cool set point changed."""
+        self._groups[GRP_HEAT_SP].set_value(degrees)
 
 
 class ClimateControl_WirelessThermostat(BatteryDeviceBase, ClimateControl_Thermostat):
@@ -430,6 +444,7 @@ class ClimateControl_WirelessThermostat(BatteryDeviceBase, ClimateControl_Thermo
 
     def __init__(self, address, cat, subcat, firmware=0x00, description="", model=""):
         """Init the Wireless Thermostat class."""
+        # pylint: disable=super-with-arguments
         super(ClimateControl_WirelessThermostat, self).__init__(
             address=address,
             cat=cat,
@@ -443,7 +458,7 @@ class ClimateControl_WirelessThermostat(BatteryDeviceBase, ClimateControl_Thermo
         )
 
     async def async_set_humidity_high_set_point(self, humidity):
-        """Set the humdity high set point."""
+        """Set the humidity high set point."""
         return self._run_on_wake(
             super(BatteryDeviceBase, self).async_set_humidity_high_set_point,
             humidity=humidity,
@@ -457,15 +472,16 @@ class ClimateControl_WirelessThermostat(BatteryDeviceBase, ClimateControl_Thermo
         )
 
     async def async_set_master(self, master):
-        """Set the thermastat master mode."""
+        """Set the thermostat master mode."""
         return self._run_on_wake(
             super(BatteryDeviceBase, self).async_set_master, master=master
         )
 
-    async def async_set_mode(self, mode):
-        """Set the thermastat mode."""
+    async def async_set_mode(self, thermostat_mode):
+        """Set the thermostat mode."""
         return self._run_on_wake(
-            super(BatteryDeviceBase, self).async_set_mode, mode=mode
+            super(BatteryDeviceBase, self).async_set_mode,
+            thermostat_mode=thermostat_mode,
         )
 
     async def async_set_notify_changes(self):
@@ -491,3 +507,26 @@ class ClimateControl_WirelessThermostat(BatteryDeviceBase, ClimateControl_Thermo
             super(BatteryDeviceBase, self).async_set_heat_set_point,
             temperature=temperature,
         )
+
+    async def async_add_default_links(self):
+        """Add default links to the device."""
+        self._run_on_wake(self.async_add_default_links_on_wake)
+
+    async def async_add_default_links_on_wake(self):
+        """Add default links to the device when the device wakes up."""
+        aldb_write_save = self.aldb.async_write
+        aldb_load_save = self.aldb.async_load
+        self.aldb.async_write = self.aldb.async_write_on_wake
+        self.aldb.async_load = self.aldb.async_load_on_wake
+
+        result_links = ResponseStatus.FAILURE
+        result_notify = ResponseStatus.FAILURE
+
+        try:
+            result_links = await async_add_default_links(self)
+            result_notify = await super().async_set_notify_changes()
+        finally:
+            self.aldb.async_write = aldb_write_save
+            self.aldb.async_load = aldb_load_save
+
+        return multiple_status(result_links, result_notify)
