@@ -1,21 +1,43 @@
 """Dimmable Lighting Control Devices (CATEGORY 0x01)."""
+import asyncio
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
-from ..constants import FanSpeed
-from ..extended_property import (
-    LED_DIMMING,
-    ON_LEVEL,
-    RAMP_RATE,
-    X10_HOUSE,
-    X10_UNIT,
-    ON_MASK,
-    OFF_MASK,
-    NON_TOGGLE_MASK,
-    TRIGGER_GROUP_MASK,
-    NON_TOGGLE_ON_OFF_MASK,
-)
-from ..events import ON_EVENT, OFF_EVENT, ON_FAST_EVENT, OFF_FAST_EVENT
 
+from ..config import (
+    CLEANUP_REPORT_ON,
+    CRC_ERROR_COUNT,
+    DATABASE_DELTA,
+    KEY_BEEP_ON,
+    LED_BLINK_ON_ERROR_OFF,
+    LED_BLINK_ON_ERROR_ON,
+    LED_BLINK_ON_TX_ON,
+    LED_DIMMING,
+    LED_OFF,
+    LOAD_SENSE_ON,
+    NON_TOGGLE_MASK,
+    NON_TOGGLE_ON_OFF_MASK,
+    OFF_MASK,
+    ON_LEVEL,
+    ON_MASK,
+    POWERLINE_DISABLE_ON,
+    PROGRAM_LOCK_ON,
+    RADIO_BUTTON_GROUPS,
+    RAMP_RATE,
+    RAMP_RATE_IN_SEC,
+    RESUME_DIM_ON,
+    RF_DISABLE_ON,
+    SIGNAL_TO_NOISE_FAILURE_COUNT,
+    TOGGLE_BUTTON,
+    TRIGGER_GROUP_MASK,
+    X10_HOUSE,
+    X10_OFF,
+    X10_UNIT,
+)
+from ..config.radio_button import RadioButtonGroupsProperty
+from ..config.ramp_rate import RampRateProperty
+from ..config.toggle_button import ToggleButtonProperty
+from ..constants import FanSpeed, PropertyType, ResponseStatus, ToggleMode
+from ..events import OFF_EVENT, OFF_FAST_EVENT, ON_EVENT, ON_FAST_EVENT
 from ..groups import (
     DIMMABLE_FAN,
     DIMMABLE_LIGHT,
@@ -30,41 +52,27 @@ from ..groups import (
     ON_OFF_SWITCH_G,
     ON_OFF_SWITCH_H,
 )
-from ..groups.on_off import OnOff
 from ..groups.on_level import OnLevel
-from ..handlers import ResponseStatus
+from ..groups.on_off import OnOff
 from ..handlers.from_device.manual_change import ManualChangeInbound
 from ..handlers.to_device.set_leds import SetLedsCommandHandler
 from ..handlers.to_device.status_request import StatusRequestCommand
-from ..operating_flag import (
-    CLEANUP_REPORT_ON,
-    CRC_ERROR_COUNT,
-    DATABASE_DELTA,
-    KEY_BEEP_ON,
-    LED_BLINK_ON_ERROR_ON,
-    LED_BLINK_ON_TX_ON,
-    LED_ON,
-    LOAD_SENSE_ON,
-    POWERLINE_DISABLE_ON,
-    PROGRAM_LOCK_ON,
-    RESUME_DIM_ON,
-    RF_DISABLE_ON,
-    SIGNAL_TO_NOISE_FAILURE_COUNT,
-    X10_OFF,
-)
-from .variable_responder_base import VariableResponderBase
-
-from .commands import (
+from ..handlers.to_device.trigger_scene_off import TriggerSceneOffCommandHandler
+from ..handlers.to_device.trigger_scene_on import TriggerSceneOnCommandHandler
+from ..utils import bit_is_set, multiple_status, set_bit, set_fan_speed
+from .device_commands import (
+    GET_LEDS_COMMAND,
     OFF_COMMAND,
     OFF_FAST_COMMAND,
     ON_COMMAND,
     ON_FAST_COMMAND,
     SET_LEDS_COMMAND,
-    GET_LEDS_COMMAND,
+    STATUS_COMMAND,
     STATUS_COMMAND_FAN,
 )
-from ..utils import set_bit, bit_is_set, multiple_status, set_fan_speed
+from .i3_base import I3VariableResponderBase
 from .variable_controller_base import ON_LEVEL_MANAGER
+from .variable_responder_base import VariableResponderBase
 
 
 class DimmableLightingControl(VariableResponderBase):
@@ -73,8 +81,11 @@ class DimmableLightingControl(VariableResponderBase):
     def _register_handlers_and_managers(self):
         """Register command handlers and managers."""
         super()._register_handlers_and_managers()
-        for group in self._groups:
-            if isinstance(self._groups[group], OnLevel):
+        self._handlers[STATUS_COMMAND] = StatusRequestCommand(
+            self._address, status_type=2
+        )
+        for group, group_prop in self._groups.items():
+            if isinstance(group_prop, OnLevel):
                 self._handlers[group]["manual_change"] = ManualChangeInbound(
                     self._address, group
                 )
@@ -82,73 +93,110 @@ class DimmableLightingControl(VariableResponderBase):
     def _subscribe_to_handelers_and_managers(self):
         """Subscribe methods to handlers and managers."""
         super()._subscribe_to_handelers_and_managers()
-        for group in self._groups:
-            if isinstance(self._groups[group], OnLevel):
-                self._handlers[group]["manual_change"].subscribe(self._on_manual_change)
+        for group, group_prop in self._groups.items():
+            if isinstance(group_prop, OnLevel):
+                self._handlers[group]["manual_change"].subscribe(
+                    self._async_on_manual_change
+                )
 
-    def _on_manual_change(self):
+    async def _async_on_manual_change(self):
         """Respond to a manual change of the device."""
-        self.status()
+        await self.async_status()
 
 
 class DimmableLightingControl_LampLinc(DimmableLightingControl):
     """LampLinc based dimmable lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
         self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(LOAD_SENSE_ON, 0, 5, 0x0A, 0x0B)
 
         self._add_property(LED_DIMMING, 3, 3)
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
-        self._add_property(RAMP_RATE, 7, 5)
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(RAMP_RATE, 7, 5, prop_type=PropertyType.ADVANCED)
         self._add_property(ON_LEVEL, 8, 6)
 
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        self._config[RAMP_RATE_IN_SEC] = RampRateProperty(
+            self._address, RAMP_RATE_IN_SEC, self._properties[RAMP_RATE]
+        )
 
-class DimmableLightingControl_SwitchLinc(DimmableLightingControl):
+
+class DimmableLightingControl_SwitchLincBase(DimmableLightingControl):
     """SwichLinc based dimmable lights."""
 
-    def _register_operating_flags(self):
-
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
         self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
         self._add_operating_flag(LED_BLINK_ON_ERROR_ON, 5, 2, 0x14, 0x15)
 
-        self._add_property(LED_DIMMING, 3, 3)
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
-        self._add_property(RAMP_RATE, 7, 5)
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(RAMP_RATE, 7, 5, prop_type=PropertyType.ADVANCED)
         self._add_property(ON_LEVEL, 8, 6)
 
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        self._config[RAMP_RATE_IN_SEC] = RampRateProperty(
+            self._address, RAMP_RATE_IN_SEC, self._properties[RAMP_RATE]
+        )
 
-class DimmableLightingControl_ToggleLinc(DimmableLightingControl):
+
+class DimmableLightingControl_SwitchLinc01(DimmableLightingControl_SwitchLincBase):
+    """SwichLinc based dimmable lights.
+
+    Uses command 0x2E 0x00 0x00 0x03 for LED dimming.
+    """
+
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
+        if (self._subcat == 0x04 and self._firmware >= 0x30) or (
+            self._subcat == 0x19 and self._firmware >= 0x41
+        ):
+            self._add_property(LED_DIMMING, 9, 7)
+        else:
+            self._add_property(LED_DIMMING, 3, 3)
+
+
+class DimmableLightingControl_SwitchLinc02(DimmableLightingControl_SwitchLincBase):
+    """SwichLinc based dimmable lights.
+
+    Uses command 0x2E 0x00 0x00 0x07 for LED dimming.
+    """
+
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
+        self._add_property(LED_DIMMING, 9, 7)
+
+
+class DimmableLightingControl_ToggleLinc(DimmableLightingControl_SwitchLinc01):
     """SwichLinc based dimmable lights."""
 
-    def _register_operating_flags(self):
 
-        super()._register_operating_flags()
-        self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
-        self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
-        self._add_operating_flag(LED_BLINK_ON_ERROR_ON, 5, 2, 0x14, 0x15)
+class DimmableLightingControl_InLineLinc01(DimmableLightingControl_SwitchLinc01):
+    """InLineLinc based dimmable lights.
 
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
-        self._add_property(RAMP_RATE, 7, 5)
-        self._add_property(ON_LEVEL, 8, 6)
+    Uses command 0x2E 0x00 0x00 0x03 for LED dimming.
+    """
 
 
-class DimmableLightingControl_InLineLinc(DimmableLightingControl_SwitchLinc):
-    """InLineLinc based dimmable lights."""
+class DimmableLightingControl_InLineLinc02(DimmableLightingControl_SwitchLinc02):
+    """InLineLinc based dimmable lights.
+
+    Uses command 0x2E 0x00 0x00 0x07 for LED dimming.
+    """
 
 
 class DimmableLightingControl_OutletLinc(DimmableLightingControl):
@@ -167,31 +215,38 @@ class DimmableLightingControl_OutletLinc(DimmableLightingControl):
             buttons=buttons,
         )
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
 
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
 
 
 class DimmableLightingControl_DinRail(DimmableLightingControl):
     """DINRail based dimmable lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
 
-        self._add_property(LED_DIMMING, 3, 3)
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
-        self._add_property(RAMP_RATE, 7, 5)
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(RAMP_RATE, 7, 5, prop_type=PropertyType.ADVANCED)
         self._add_property(ON_LEVEL, 8, 6)
+        self._add_property(LED_DIMMING, 9, 7)
+
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        self._config[RAMP_RATE_IN_SEC] = RampRateProperty(
+            self._address, RAMP_RATE_IN_SEC, self._properties[RAMP_RATE]
+        )
 
 
 class DimmableLightingControl_FanLinc(DimmableLightingControl):
@@ -282,17 +337,10 @@ class DimmableLightingControl_FanLinc(DimmableLightingControl):
         fan_status = await self.async_fan_status()
         if light_status == fan_status == ResponseStatus.SUCCESS:
             return ResponseStatus.SUCCESS
-        if (
-            light_status == ResponseStatus.UNCLEAR
-            or fan_status == ResponseStatus.UNCLEAR
-        ):
-            return ResponseStatus.UNCLEAR
+        if ResponseStatus.DIRECT_NAK_PRE_NAK in (light_status, fan_status):
+            return ResponseStatus.DIRECT_NAK_PRE_NAK
         return ResponseStatus.FAILURE
 
-    def light_status(self):
-        """Request the status of the light."""
-        super().status()
-
     async def async_light_status(self):
         """Request the status of the light."""
         return await super().async_status()
@@ -320,13 +368,13 @@ class DimmableLightingControl_FanLinc(DimmableLightingControl):
         super()._subscribe_to_handelers_and_managers()
         self._handlers[STATUS_COMMAND_FAN].subscribe(self._handle_fan_status)
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
 
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
         self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
         self._add_operating_flag(RF_DISABLE_ON, 0, 6, 0x0C, 0x0D)
         self._add_operating_flag(POWERLINE_DISABLE_ON, 0, 7, 0x0E, 0x0F)
@@ -339,17 +387,22 @@ class DimmableLightingControl_FanLinc(DimmableLightingControl):
         self._add_operating_flag(LED_BLINK_ON_ERROR_ON, 5, 2, 0x14, 0x15)
         self._add_operating_flag(CLEANUP_REPORT_ON, 5, 3, 0x16, 0x17)
 
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
-        self._add_property(RAMP_RATE, 7, 5)
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(RAMP_RATE, 7, 5, prop_type=PropertyType.ADVANCED)
         self._add_property(ON_LEVEL, 8, 6)
 
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        self._config[RAMP_RATE_IN_SEC] = RampRateProperty(
+            self._address, RAMP_RATE_IN_SEC, self._properties[RAMP_RATE]
+        )
+
     def _handle_fan_status(self, db_version, status):
         self._groups[2].set_value(status)
 
 
-# TODO setup operating flags for each KPL button
-# TODO trigger scenes
 class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
     """KeypadLinc base class."""
 
@@ -367,18 +420,20 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
         super().__init__(
             address, cat, subcat, firmware, description, model, buttons=buttons
         )
+        self._on_off_lock = asyncio.Lock()
 
     async def async_on(self, on_level: int = 0xFF, group: int = 0, fast: bool = False):
         """Turn on the button LED."""
         if group in [0, 1]:
             result = await super().async_on(on_level=on_level, group=group, fast=fast)
         else:
-            kwargs = self._change_led_status(led=group, is_on=True)
-            result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
+            async with self._on_off_lock:
+                kwargs = self._change_led_status(led=group, is_on=True)
+                result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
         if result == ResponseStatus.SUCCESS:
             event = ON_FAST_EVENT if fast else ON_EVENT
             self._update_leds(group=group, value=on_level, event=event)
-        elif result == ResponseStatus.UNCLEAR:
+        elif result == ResponseStatus.DIRECT_NAK_PRE_NAK:
             await self.async_status()
         return result
 
@@ -387,15 +442,28 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
         if group in [0, 1]:
             result = await super().async_off(group=group, fast=fast)
         else:
-            kwargs = self._change_led_status(led=group, is_on=False)
-            result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
+            async with self._on_off_lock:
+                kwargs = self._change_led_status(led=group, is_on=False)
+                result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
         if result == ResponseStatus.SUCCESS:
             event = OFF_FAST_EVENT if fast else OFF_EVENT
             self._update_leds(group=group, value=0, event=event)
-        elif result == ResponseStatus.UNCLEAR:
+        elif result == ResponseStatus.DIRECT_NAK_PRE_NAK:
             await self.async_status()
         return result
 
+    async def async_trigger_scene_on(
+        self, group: int, on_level: int = 255, fast: bool = False
+    ):
+        """Trigger an All-Link group on."""
+        cmd = TriggerSceneOnCommandHandler(self._address, group)
+        return await cmd.async_send(on_level, fast)
+
+    async def async_trigger_scene_off(self, group: int, fast: bool = False):
+        """Trigger an All-Link group off."""
+        cmd = TriggerSceneOffCommandHandler(self._address, group)
+        return await cmd.async_send(fast)
+
     async def async_status(self):
         """Check the status of the device."""
         retries = 5
@@ -407,7 +475,7 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
             retries -= 1
         return status
 
-    async def async_set_radio_buttons(self, buttons: Iterable):
+    def set_radio_buttons(self, buttons: Iterable):
         """Set a group of buttons to act as radio buttons.
 
         This takes in a iterable set of buttons (eg. (3,4,5,6)) to act as radio buttons where
@@ -415,13 +483,16 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
         """
         if len(buttons) < 2:
             raise IndexError("At least two buttons required.")
-        await self.async_read_ext_properties()
+
         for button in buttons:
             if button not in self._buttons.keys():
                 raise ValueError(f"Button {button} not in button list.")
             button_str = f"_{button}" if button != 1 else ""
             on_mask = self._properties[f"{ON_MASK}{button_str}"]
             off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            if not on_mask.is_loaded or not off_mask.is_loaded:
+                on_mask.load(0)
+                off_mask.load(0)
             on_mask_new_value = 0
             off_mask_new_value = 0
             for bit in range(0, 8):
@@ -435,35 +506,112 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
                 off_mask_new_value = set_bit(off_mask_new_value, bit, off_mask_value)
             on_mask.new_value = on_mask_new_value
             off_mask.new_value = off_mask_new_value
-        await self.async_write_ext_properties()
 
-    async def async_set_toggle_mode(self, button: int, mode: int):
+    def clear_radio_buttons(self, buttons: Iterable):
+        """Clear the radio button behavior of the button.
+
+        This takes in a single button number or a collection of buttons.
+        For any button received, the radio button behavior of that button and
+        any button that is grouped with that button will be cleared.
+
+        Example:
+            - Buttons C and D are currently radio buttons
+            - Call `clear_radio_buttons(3)` which represents the C button.
+            - Because C and D are currently grouped as radio buttons,
+              both C and D will have their on and off masks changed to clear the
+              link to the other button.
+
+        """
+        other_buttons = [
+            button for button in self._buttons if button not in buttons and button != 1
+        ]
+        addl_buttons = []
+        for other_button in other_buttons:
+            button_str = f"_{other_button}" if other_button != 1 else ""
+            on_mask = self._properties[f"{ON_MASK}{button_str}"]
+            off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            if on_mask.is_loaded and off_mask.is_loaded:
+                for button in buttons:
+                    bit = button - 1
+                    on_set = (
+                        bit_is_set(on_mask.new_value, bit)
+                        if on_mask.is_dirty
+                        else bit_is_set(on_mask.value, bit)
+                    )
+                    off_set = (
+                        bit_is_set(off_mask.new_value, bit)
+                        if off_mask.is_dirty
+                        else bit_is_set(off_mask.value, bit)
+                    )
+                    if on_set or off_set and other_button not in addl_buttons:
+                        addl_buttons.append(other_button)
+                        continue
+
+        for button in buttons:
+            button_str = f"_{button}" if button != 1 else ""
+            on_mask = self._properties[f"{ON_MASK}{button_str}"]
+            off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            on_mask.new_value = 0
+            off_mask.new_value = 0
+
+        for addl_button in addl_buttons:
+            button_str = f"_{addl_button}" if addl_button != 1 else ""
+            on_mask = self._properties[f"{ON_MASK}{button_str}"]
+            off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            for button in buttons:
+                if on_mask.is_dirty:
+                    on_mask.new_value = set_bit(on_mask.new_value, button - 1, False)
+                else:
+                    on_mask.new_value = set_bit(on_mask.value, button - 1, False)
+                if off_mask.is_dirty:
+                    off_mask.new_value = set_bit(off_mask.new_value, button - 1, False)
+                else:
+                    off_mask.new_value = set_bit(off_mask.value, button - 1, False)
+
+    def set_toggle_mode(self, button: int, toggle_mode: ToggleMode):
         """Set the toggle mode of a button.
 
         Usage:
             button: Integer of the button number
-            mode: Integer of the mode
+            toggle_mode: Integer of the toggle mode
                 0: Toggle
                 1: Non-Toggle ON only
                 2: Non-Toggle OFF only
         """
         if button not in self._buttons.keys():
             raise ValueError(f"Button {button} not in button list.")
-        if mode not in [0, 1, 2]:
-            raise ValueError(f"Mode {mode} invalid. Valid mode are [0, 1, 2]")
-        await self.async_read_ext_properties(group=1)
+        try:
+            toggle_mode = ToggleMode(toggle_mode)
+        except ValueError as err:
+            raise ValueError(
+                f"Toggle mode {toggle_mode} invalid. Valid modes are [0, 1, 2]"
+            ) from err
+
         toggle_mask = self.properties[NON_TOGGLE_MASK]
         on_off_mask = self.properties[NON_TOGGLE_ON_OFF_MASK]
-        if mode == 0:
-            toggle_mask.new_value = set_bit(toggle_mask.value, button - 1, False)
-            on_off_mask.new_value = set_bit(on_off_mask.value, button - 1, False)
-        elif mode == 1:
-            toggle_mask.new_value = set_bit(toggle_mask.value, button - 1, True)
-            on_off_mask.new_value = set_bit(on_off_mask.value, button - 1, True)
+        if not toggle_mask.is_loaded or not on_off_mask.is_loaded:
+            toggle_mask.load(0)
+            on_off_mask.load(0)
+
+        if toggle_mask.new_value is None:
+            toggle_mask_test = toggle_mask.value
         else:
-            toggle_mask.new_value = set_bit(toggle_mask.value, button - 1, True)
-            on_off_mask.new_value = set_bit(on_off_mask.value, button - 1, False)
-        await self.async_write_ext_properties()
+            toggle_mask_test = toggle_mask.new_value
+
+        if on_off_mask.new_value is None:
+            on_off_mask_test = on_off_mask.value
+        else:
+            on_off_mask_test = on_off_mask.new_value
+
+        if toggle_mode == ToggleMode.TOGGLE:
+            toggle_mask.new_value = set_bit(toggle_mask_test, button - 1, False)
+            on_off_mask.new_value = set_bit(on_off_mask_test, button - 1, False)
+        elif toggle_mode == ToggleMode.ON_ONLY:
+            toggle_mask.new_value = set_bit(toggle_mask_test, button - 1, True)
+            on_off_mask.new_value = set_bit(on_off_mask_test, button - 1, True)
+        else:
+            toggle_mask.new_value = set_bit(toggle_mask_test, button - 1, True)
+            on_off_mask.new_value = set_bit(on_off_mask_test, button - 1, False)
 
     def _register_handlers_and_managers(self):
         super()._register_handlers_and_managers()
@@ -471,8 +619,8 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
         self._handlers[GET_LEDS_COMMAND] = StatusRequestCommand(
             self._address, status_type=1
         )
-        for group in self._groups:
-            if isinstance(self._groups[group], OnLevel):
+        for group, group_prop in self._groups.items():
+            if isinstance(group_prop, OnLevel):
                 self._handlers[group]["manual_change"] = ManualChangeInbound(
                     self._address, group
                 )
@@ -493,7 +641,7 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
         super()._subscribe_to_handelers_and_managers()
         self._handlers[GET_LEDS_COMMAND].subscribe(self._led_status)
         for group in self._buttons:
-            if self._groups.get(group) is not None:
+            if group != 1:
                 led_method = partial(self._led_follow_check, group=group)
                 self._managers[group][ON_LEVEL_MANAGER].subscribe(led_method)
 
@@ -516,7 +664,7 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
     def _change_led_status(self, led, is_on):
         leds = {}
         for curr_led in range(1, 9):
-            var = "group{}".format(curr_led)
+            var = f"group{curr_led}"
             curr_group = self._groups.get(curr_led)
             curr_val = bool(curr_group.value) if curr_group else False
             leds[var] = is_on if curr_led == led else curr_val
@@ -543,32 +691,80 @@ class DimmableLightingControl_KeypadLinc(DimmableLightingControl):
             if state:
                 state.value = bit_is_set(status, bit - 1)
 
-    def _register_operating_flags(self):
+    def _register_op_flags_and_props(self):
         """Register operating flags."""
-        super()._register_operating_flags()
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
         self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
         self._add_operating_flag(RF_DISABLE_ON, 0, 6, 0x0C, 0x0D)
         self._add_operating_flag(POWERLINE_DISABLE_ON, 0, 7, 0x0E, 0x0F)
-        self._add_operating_flag(
-            LED_BLINK_ON_ERROR_ON, 5, 2, 0x14, 0x15, is_reversed=True
-        )
+        self._add_operating_flag(LED_BLINK_ON_ERROR_OFF, 5, 2, 0x14, 0x15)
 
         self._add_property(LED_DIMMING, 9, 7, 1)
-        self._add_property(NON_TOGGLE_MASK, 0x0A, 0x08)
-        self._add_property(NON_TOGGLE_ON_OFF_MASK, 0x0D, 0x0B)
-        self._add_property(TRIGGER_GROUP_MASK, 0x0E, 0x0C)
+        self._add_property(NON_TOGGLE_MASK, 0x0A, 0x08, prop_type=PropertyType.ADVANCED)
+        self._add_property(
+            NON_TOGGLE_ON_OFF_MASK, 0x0D, 0x0B, prop_type=PropertyType.ADVANCED
+        )
+        self._add_property(
+            TRIGGER_GROUP_MASK, 0x0E, 0x0C, prop_type=PropertyType.ADVANCED
+        )
         for button in self._buttons:
             button_str = f"_{button}" if button != 1 else ""
-            self._add_property(f"{ON_MASK}{button_str}", 3, 2, button)
-            self._add_property(f"{OFF_MASK}{button_str}", 4, 3, button)
-            self._add_property(f"{X10_HOUSE}{button_str}", 5, None, button)
-            self._add_property(f"{X10_UNIT}{button_str}", 6, None, button)
-            self._add_property(f"{RAMP_RATE}{button_str}", 7, 5, button)
-            self._add_property(f"{ON_LEVEL}{button_str}", 8, 6, button)
+            self._add_property(
+                f"{ON_MASK}{button_str}", 3, 2, button, prop_type=PropertyType.ADVANCED
+            )
+            self._add_property(
+                f"{OFF_MASK}{button_str}", 4, 3, button, prop_type=PropertyType.ADVANCED
+            )
+            self._add_property(
+                f"{X10_HOUSE}{button_str}",
+                5,
+                None,
+                button,
+                prop_type=PropertyType.ADVANCED,
+            )
+            self._add_property(
+                f"{X10_UNIT}{button_str}",
+                6,
+                None,
+                button,
+                prop_type=PropertyType.ADVANCED,
+            )
+            self._add_property(
+                f"{RAMP_RATE}{button_str}",
+                7,
+                5,
+                button,
+                prop_type=PropertyType.ADVANCED,
+            )
+            self._add_property(
+                f"{ON_LEVEL}{button_str}", 8, 6, button, prop_type=PropertyType.ADVANCED
+            )
+
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        self._config[RAMP_RATE_IN_SEC] = RampRateProperty(
+            self._address, RAMP_RATE_IN_SEC, self._properties[RAMP_RATE]
+        )
+        self._config[RADIO_BUTTON_GROUPS] = RadioButtonGroupsProperty(
+            self, RADIO_BUTTON_GROUPS
+        )
+        for group in self._groups:
+            if group == 1:
+                continue
+            button = self._buttons[group]
+            name = f"{TOGGLE_BUTTON}_{button[-1]}"
+            self._config[name] = ToggleButtonProperty(
+                self._address,
+                name,
+                group,
+                self.properties[NON_TOGGLE_MASK],
+                self.properties[NON_TOGGLE_ON_OFF_MASK],
+            )
 
 
 class DimmableLightingControl_KeypadLinc_6(DimmableLightingControl_KeypadLinc):
@@ -618,3 +814,41 @@ class DimmableLightingControl_KeypadLinc_8(DimmableLightingControl_KeypadLinc):
             model=model,
             buttons=buttons,
         )
+
+
+class DimmableLightingControl_Dial(I3VariableResponderBase):
+    """Dimmable i3 Dial."""
+
+    def _register_handlers_and_managers(self):
+        """Register command handlers and managers."""
+        super()._register_handlers_and_managers()
+        self._handlers[STATUS_COMMAND] = StatusRequestCommand(
+            self._address, status_type=2
+        )
+        for group, group_prop in self._groups.items():
+            if isinstance(group_prop, OnLevel):
+                self._handlers[group]["manual_change"] = ManualChangeInbound(
+                    self._address, group
+                )
+        self._register_default_ext_prop_read_managers()
+        self._register_default_ext_prop_write_managers()
+
+    def _subscribe_to_handelers_and_managers(self):
+        """Subscribe methods to handlers and managers."""
+        super()._subscribe_to_handelers_and_managers()
+        for group, group_prop in self._groups.items():
+            if isinstance(group_prop, OnLevel):
+                self._handlers[group]["manual_change"].subscribe(
+                    self._async_on_manual_change
+                )
+
+    async def _async_on_manual_change(self):
+        """Respond to a manual change of the device."""
+        await self.async_status()
+
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        self._config[RAMP_RATE_IN_SEC] = RampRateProperty(
+            self._address, RAMP_RATE_IN_SEC, self._properties[RAMP_RATE]
+        )
