@@ -1,6 +1,6 @@
 """Insteon Powerline Modem (PLM)."""
 
-from ..aldb.plm_aldb import PlmALDB
+from ..aldb.modem_aldb import ModemALDB
 from .modem_base import ModemBase
 
 
@@ -18,4 +18,8 @@ class PLM(ModemBase):
     ):
         """Init the Modem class."""
         super().__init__(address, cat, subcat, firmware, description, model)
-        self._aldb = PlmALDB(self._address)
+        if subcat in [0x05, 0x06, 0x0B, 0x10, 0x13, 0x14]:
+            mem_addr = 0x3FFF
+        else:
+            mem_addr = 0x1FFF
+        self._aldb = ModemALDB(self._address, mem_addr=mem_addr)
