@@ -1,19 +1,42 @@
 """Switched Lighting Control devices (CATEGORY 0x02)."""
+import asyncio
 from functools import partial
 from typing import Iterable
 
-from ..constants import ResponseStatus
-from ..events import OFF_EVENT, OFF_FAST_EVENT, ON_EVENT, ON_FAST_EVENT
-from ..extended_property import (
+from ..config import (
+    BLUE_LED_OFF,
+    DUAL_LINE_ON,
+    GREEN_LED_OFF,
+    KEY_BEEP_ON,
+    LED_BLINK_ON_ERROR_OFF,
+    LED_BLINK_ON_ERROR_ON,
+    LED_BLINK_ON_TX_ON,
     LED_DIMMING,
-    X10_HOUSE,
-    X10_UNIT,
-    ON_MASK,
-    OFF_MASK,
+    LED_OFF,
+    LOAD_SENSE_2_ON,
+    LOAD_SENSE_ON,
+    MOMENTARY_LINE_ON,
     NON_TOGGLE_MASK,
     NON_TOGGLE_ON_OFF_MASK,
+    OFF_MASK,
+    ON_MASK,
+    POWERLINE_DISABLE_ON,
+    PROGRAM_LOCK_ON,
+    RADIO_BUTTON_GROUPS,
+    RED_LED_OFF,
+    RESUME_DIM_ON,
+    REVERSED_ON,
+    RF_DISABLE_ON,
+    THREE_WAY_ON,
+    TOGGLE_BUTTON,
     TRIGGER_GROUP_MASK,
+    X10_HOUSE,
+    X10_UNIT,
 )
+from ..config.radio_button import RadioButtonGroupsProperty
+from ..config.toggle_button import ToggleButtonProperty
+from ..constants import PropertyType, ResponseStatus, ToggleMode
+from ..events import OFF_EVENT, OFF_FAST_EVENT, ON_EVENT, ON_FAST_EVENT
 from ..groups import (
     ON_OFF_OUTLET_BOTTOM,
     ON_OFF_OUTLET_TOP,
@@ -31,24 +54,11 @@ from ..groups import (
 from ..groups.on_off import OnOff
 from ..handlers.to_device.set_leds import SetLedsCommandHandler
 from ..handlers.to_device.status_request import StatusRequestCommand
-from ..operating_flag import (
-    DUAL_LINE_ON,
-    KEY_BEEP_ON,
-    LED_BLINK_ON_ERROR_ON,
-    LED_BLINK_ON_TX_ON,
-    LED_ON,
-    MOMENTARY_LINE_ON,
-    PROGRAM_LOCK_ON,
-    RESUME_DIM_ON,
-    REVERSED_ON,
-    THREE_WAY_ON,
-    RF_DISABLE_ON,
-    POWERLINE_DISABLE_ON,
-)
-from .commands import SET_LEDS_COMMAND, STATUS_COMMAND, GET_LEDS_COMMAND
-from .on_off_responder_base import OnOffResponderBase
-from ..utils import bit_is_set, set_bit, multiple_status
+from ..utils import bit_is_set, multiple_status, set_bit
+from .device_commands import GET_LEDS_COMMAND, SET_LEDS_COMMAND, STATUS_COMMAND
+from .i3_base import I3Base
 from .on_off_controller_base import ON_LEVEL_MANAGER
+from .on_off_responder_base import OnOffResponderBase
 
 
 class SwitchedLightingControl(OnOffResponderBase):
@@ -89,70 +99,90 @@ class SwitchedLightingControl(OnOffResponderBase):
 class SwitchedLightingControl_ApplianceLinc(SwitchedLightingControl):
     """ApplianceLinc based dimmable lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
 
 
-class SwitchedLightingControl_SwitchLinc(SwitchedLightingControl):
+class SwitchedLightingControl_SwitchLincBase(SwitchedLightingControl):
     """SwichLinc based dimmable lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
         self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
         self._add_operating_flag(LED_BLINK_ON_ERROR_ON, 5, 2, 0x14, 0x15)
 
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
+
+
+class SwitchedLightingControl_SwitchLinc01(SwitchedLightingControl_SwitchLincBase):
+    """SwichLinc based dimmable lights.
+
+    Uses command 0x2E 0x00 0x00 0x03 for LED dimming.
+    """
+
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_property(LED_DIMMING, 3, 3)
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
 
 
-class SwitchedLightingControl_ToggleLinc(SwitchedLightingControl):
+class SwitchedLightingControl_SwitchLinc02(SwitchedLightingControl_SwitchLincBase):
+    """SwichLinc based dimmable lights.
+
+    Uses command 0x2E 0x00 0x00 0x07 for LED dimming.
+    """
+
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
+        self._add_property(LED_DIMMING, 9, 7)
+
+
+class SwitchedLightingControl_ToggleLinc(SwitchedLightingControl_SwitchLinc01):
     """ToggleLinc based on/off lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
-        self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
-        self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
-        self._add_operating_flag(LED_BLINK_ON_ERROR_ON, 5, 2, 0x14, 0x15)
 
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
+class SwitchedLightingControl_InLineLinc01(SwitchedLightingControl_SwitchLinc01):
+    """InLineLinc based dimmable lights..
+
+    Uses command 0x2E 0x00 0x00 0x03 for LED dimming.
+    """
 
 
-class SwitchedLightingControl_InLineLinc(SwitchedLightingControl_SwitchLinc):
-    """InLineLinc based dimmable lights."""
+class SwitchedLightingControl_InLineLinc02(SwitchedLightingControl_SwitchLinc02):
+    """InLineLinc based dimmable lights..
+
+    Uses command 0x2E 0x00 0x00 0x07 for LED dimming.
+    """
 
 
 class SwitchedLightingControl_OutletLinc(SwitchedLightingControl):
     """OutletLinc based dimmable lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
 
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
 
 
 class SwitchedLightingControl_Micro(SwitchedLightingControl):
     """Micro switch based dimmable lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
 
         self._add_operating_flag(LED_BLINK_ON_ERROR_ON, 2, 2, 0x15, 0x14)
@@ -166,16 +196,16 @@ class SwitchedLightingControl_Micro(SwitchedLightingControl):
 class SwitchedLightingControl_DinRail(SwitchedLightingControl):
     """DINRail based dimmable lights."""
 
-    def _register_operating_flags(self):
-        super()._register_operating_flags()
+    def _register_op_flags_and_props(self):
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
 
-        self._add_property(LED_DIMMING, 3, 3)
-        self._add_property(X10_HOUSE, 5, None)
-        self._add_property(X10_UNIT, 6, None)
+        self._add_property(X10_HOUSE, 5, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(X10_UNIT, 6, None, prop_type=PropertyType.ADVANCED)
+        self._add_property(LED_DIMMING, 9, 7)
 
 
 class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
@@ -195,17 +225,19 @@ class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
         super().__init__(
             address, cat, subcat, firmware, description, model, buttons=buttons
         )
+        self._on_off_lock = asyncio.Lock()
 
     async def async_on(self, group: int = 0):
         """Turn on the button LED."""
         if group in [0, 1]:
             result = await super().async_on(group=group)
         else:
-            kwargs = self._change_led_status(led=group, is_on=True)
-            result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
+            async with self._on_off_lock:
+                kwargs = self._change_led_status(led=group, is_on=True)
+                result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
         if result == ResponseStatus.SUCCESS:
             self._update_leds(group=group, value=0xFF, event=ON_EVENT)
-        elif result == ResponseStatus.UNCLEAR:
+        elif result == ResponseStatus.DIRECT_NAK_PRE_NAK:
             await self.async_status()
         return result
 
@@ -214,11 +246,12 @@ class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
         if group in [0, 1]:
             result = await super().async_off(group=group)
         else:
-            kwargs = self._change_led_status(led=group, is_on=False)
-            result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
+            async with self._on_off_lock:
+                kwargs = self._change_led_status(led=group, is_on=False)
+                result = await self._handlers[SET_LEDS_COMMAND].async_send(**kwargs)
         if result == ResponseStatus.SUCCESS:
             self._update_leds(group=group, value=0, event=OFF_EVENT)
-        elif result == ResponseStatus.UNCLEAR:
+        elif result == ResponseStatus.DIRECT_NAK_PRE_NAK:
             await self.async_status()
         return result
 
@@ -233,7 +266,7 @@ class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
             retries -= 1
         return status
 
-    async def async_set_radio_buttons(self, buttons: Iterable):
+    def set_radio_buttons(self, buttons: Iterable):
         """Set a group of buttons to act as radio buttons.
 
         This takes in a iterable set of buttons (eg. (3,4,5,6)) to act as radio buttons where
@@ -241,13 +274,16 @@ class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
         """
         if len(buttons) < 2:
             raise IndexError("At least two buttons required.")
-        await self.async_read_ext_properties()
+
         for button in buttons:
             if button not in self._buttons.keys():
                 raise ValueError(f"Button {button} not in button list.")
             button_str = f"_{button}" if button != 1 else ""
             on_mask = self._properties[f"{ON_MASK}{button_str}"]
             off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            if not on_mask.is_loaded or not off_mask.is_loaded:
+                on_mask.load(0)
+                off_mask.load(0)
             on_mask_new_value = 0
             off_mask_new_value = 0
             for bit in range(0, 8):
@@ -261,38 +297,119 @@ class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
                 off_mask_new_value = set_bit(off_mask_new_value, bit, off_mask_value)
             on_mask.new_value = on_mask_new_value
             off_mask.new_value = off_mask_new_value
-        await self.async_write_ext_properties()
 
-    async def async_set_toggle_mode(self, button: int, mode: int):
+    def clear_radio_buttons(self, buttons: Iterable):
+        """Clear the radio button behavior of the button.
+
+        This takes in a single button number or a collection of buttons.
+        For any button received, the radio button behavior of that button and
+        any button that is grouped with that button will be cleared.
+
+        Example:
+            - Buttons C and D are currently radio buttons
+            - Call `clear_radio_buttons(3)` which represents the C button.
+            - Because C and D are currently grouped as radio buttons,
+              both C and D will have their on and off masks changed to clear the
+              link to the other button.
+
+        """
+        other_buttons = [
+            button for button in self._buttons if button not in buttons and button != 1
+        ]
+        addl_buttons = []
+        for other_button in other_buttons:
+            button_str = f"_{other_button}" if other_button != 1 else ""
+            on_mask = self._properties[f"{ON_MASK}{button_str}"]
+            off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            if on_mask.is_loaded and off_mask.is_loaded:
+                for button in buttons:
+                    bit = button - 1
+                    on_set = (
+                        bit_is_set(on_mask.new_value, bit)
+                        if on_mask.is_dirty
+                        else bit_is_set(on_mask.value, bit)
+                    )
+                    off_set = (
+                        bit_is_set(off_mask.new_value, bit)
+                        if off_mask.is_dirty
+                        else bit_is_set(off_mask.value, bit)
+                    )
+                    if on_set or off_set and other_button not in addl_buttons:
+                        addl_buttons.append(other_button)
+                        continue
+
+        for button in buttons:
+            button_str = f"_{button}" if button != 1 else ""
+            on_mask = self._properties[f"{ON_MASK}{button_str}"]
+            off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            on_mask.new_value = 0
+            off_mask.new_value = 0
+
+        for addl_button in addl_buttons:
+            button_str = f"_{addl_button}" if addl_button != 1 else ""
+            on_mask = self._properties[f"{ON_MASK}{button_str}"]
+            off_mask = self._properties[f"{OFF_MASK}{button_str}"]
+            for button in buttons:
+                if on_mask.is_dirty:
+                    on_mask.new_value = set_bit(on_mask.new_value, button - 1, False)
+                else:
+                    on_mask.new_value = set_bit(on_mask.value, button - 1, False)
+                if off_mask.is_dirty:
+                    off_mask.new_value = set_bit(off_mask.new_value, button - 1, False)
+                else:
+                    off_mask.new_value = set_bit(off_mask.value, button - 1, False)
+
+    def set_toggle_mode(self, button: int, toggle_mode: ToggleMode):
         """Set the toggle mode of a button.
 
         Usage:
             button: Integer of the button number
-            mode: Integer of the mode
+            toggle_mode: Integer of the toggle mode
                 0: Toggle
                 1: Non-Toggle ON only
                 2: Non-Toggle OFF only
         """
         if button not in self._buttons.keys():
             raise ValueError(f"Button {button} not in button list.")
-        if mode not in [0, 1, 2]:
-            raise ValueError(f"Mode {mode} invalid. Valid mode are [0, 1, 2]")
-        await self.async_read_ext_properties(group=1)
+
+        try:
+            toggle_mode = ToggleMode(toggle_mode)
+        except ValueError as err:
+            raise ValueError(
+                f"Toggle mode {toggle_mode} invalid. Valid modes are [0, 1, 2]"
+            ) from err
+
         toggle_mask = self.properties[NON_TOGGLE_MASK]
         on_off_mask = self.properties[NON_TOGGLE_ON_OFF_MASK]
-        if mode == 0:
-            toggle_mask.new_value = set_bit(toggle_mask.value, button - 1, False)
-            on_off_mask.new_value = set_bit(on_off_mask.value, button - 1, False)
-        elif mode == 1:
-            toggle_mask.new_value = set_bit(toggle_mask.value, button - 1, True)
-            on_off_mask.new_value = set_bit(on_off_mask.value, button - 1, True)
+        if not toggle_mask.is_loaded or not on_off_mask.is_loaded:
+            toggle_mask.load(0)
+            on_off_mask.load(0)
+
+        if toggle_mask.new_value is None:
+            toggle_mask_test = toggle_mask.value
         else:
-            toggle_mask.new_value = set_bit(toggle_mask.value, button - 1, True)
-            on_off_mask.new_value = set_bit(on_off_mask.value, button - 1, False)
-        await self.async_write_ext_properties()
+            toggle_mask_test = toggle_mask.new_value
+
+        if on_off_mask.new_value is None:
+            on_off_mask_test = on_off_mask.value
+        else:
+            on_off_mask_test = on_off_mask.new_value
+
+        if toggle_mode == ToggleMode.TOGGLE:
+            toggle_mask.new_value = set_bit(toggle_mask_test, button - 1, False)
+            on_off_mask.new_value = set_bit(on_off_mask_test, button - 1, False)
+        elif toggle_mode == ToggleMode.ON_ONLY:
+            toggle_mask.new_value = set_bit(toggle_mask_test, button - 1, True)
+            on_off_mask.new_value = set_bit(on_off_mask_test, button - 1, True)
+        else:
+            toggle_mask.new_value = set_bit(toggle_mask_test, button - 1, True)
+            on_off_mask.new_value = set_bit(on_off_mask_test, button - 1, False)
 
     def _register_handlers_and_managers(self):
         super()._register_handlers_and_managers()
+        self._handlers[STATUS_COMMAND] = StatusRequestCommand(
+            self._address, status_type=2
+        )
         self._handlers[SET_LEDS_COMMAND] = SetLedsCommandHandler(address=self.address)
         self._handlers[GET_LEDS_COMMAND] = StatusRequestCommand(
             self._address, status_type=1
@@ -331,7 +448,7 @@ class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
     def _change_led_status(self, led, is_on):
         leds = {}
         for curr_led in range(1, 9):
-            var = "group{}".format(curr_led)
+            var = f"group{curr_led}"
             curr_group = self._groups.get(curr_led)
             curr_val = bool(curr_group.value) if curr_group else False
             leds[var] = is_on if curr_led == led else curr_val
@@ -358,30 +475,67 @@ class SwitchedLightingControl_KeypadLinc(SwitchedLightingControl):
             if state:
                 state.value = bit_is_set(status, bit - 1)
 
-    def _register_operating_flags(self):
+    def _register_op_flags_and_props(self):
         """Register operating flags."""
-        super()._register_operating_flags()
+        super()._register_op_flags_and_props()
         self._add_operating_flag(PROGRAM_LOCK_ON, 0, 0, 0, 1)
         self._add_operating_flag(LED_BLINK_ON_TX_ON, 0, 1, 2, 3)
         self._add_operating_flag(RESUME_DIM_ON, 0, 2, 4, 5)
-        self._add_operating_flag(LED_ON, 0, 4, 8, 9, is_reversed=True)
+        self._add_operating_flag(LED_OFF, 0, 4, 8, 9)
         self._add_operating_flag(KEY_BEEP_ON, 0, 5, 0x0A, 0x0B)
         self._add_operating_flag(RF_DISABLE_ON, 0, 6, 0x0C, 0x0D)
         self._add_operating_flag(POWERLINE_DISABLE_ON, 0, 7, 0x0E, 0x0F)
-        self._add_operating_flag(
-            LED_BLINK_ON_ERROR_ON, 5, 2, 0x14, 0x15, is_reversed=True
-        )
+        self._add_operating_flag(LED_BLINK_ON_ERROR_OFF, 5, 2, 0x14, 0x15)
 
         self._add_property(LED_DIMMING, 9, 7, 1)
-        self._add_property(NON_TOGGLE_MASK, 0x0A, 0x08)
-        self._add_property(NON_TOGGLE_ON_OFF_MASK, 0x0D, 0x0B)
-        self._add_property(TRIGGER_GROUP_MASK, 0x0E, 0x0C)
+        self._add_property(NON_TOGGLE_MASK, 0x0A, 0x08, prop_type=PropertyType.ADVANCED)
+        self._add_property(
+            NON_TOGGLE_ON_OFF_MASK, 0x0D, 0x0B, prop_type=PropertyType.ADVANCED
+        )
+        self._add_property(
+            TRIGGER_GROUP_MASK, 0x0E, 0x0C, prop_type=PropertyType.ADVANCED
+        )
         for button in self._buttons:
             button_str = f"_{button}" if button != 1 else ""
-            self._add_property(f"{ON_MASK}{button_str}", 3, 2, button)
-            self._add_property(f"{OFF_MASK}{button_str}", 4, 3, button)
-            self._add_property(f"{X10_HOUSE}{button_str}", 5, None, button)
-            self._add_property(f"{X10_UNIT}{button_str}", 6, None, button)
+            self._add_property(
+                f"{ON_MASK}{button_str}", 3, 2, button, prop_type=PropertyType.ADVANCED
+            )
+            self._add_property(
+                f"{OFF_MASK}{button_str}", 4, 3, button, prop_type=PropertyType.ADVANCED
+            )
+            self._add_property(
+                f"{X10_HOUSE}{button_str}",
+                5,
+                None,
+                button,
+                prop_type=PropertyType.ADVANCED,
+            )
+            self._add_property(
+                f"{X10_UNIT}{button_str}",
+                6,
+                None,
+                button,
+                prop_type=PropertyType.ADVANCED,
+            )
+
+    def _register_config(self):
+        """Register configuration items."""
+        super()._register_config()
+        self._config[RADIO_BUTTON_GROUPS] = RadioButtonGroupsProperty(
+            self, RADIO_BUTTON_GROUPS
+        )
+        for group in self._groups:
+            if group == 1:
+                continue
+            button = self._buttons[group]
+            name = f"{TOGGLE_BUTTON}_{button[-1]}"
+            self._config[name] = ToggleButtonProperty(
+                self._address,
+                name,
+                group,
+                self.properties[NON_TOGGLE_MASK],
+                self.properties[NON_TOGGLE_ON_OFF_MASK],
+            )
 
 
 class SwitchedLightingControl_KeypadLinc_6(SwitchedLightingControl_KeypadLinc):
@@ -475,9 +629,9 @@ class SwitchedLightingControl_OnOffOutlet(SwitchedLightingControl_ApplianceLinc)
 
         if self._handlers.get(self.BOTTOM_GROUP) is None:
             self._handlers[self.BOTTOM_GROUP] = {}
-        self._handlers[self.BOTTOM_GROUP][STATUS_COMMAND] = StatusRequestCommand(
-            self._address, 0
-        )
+        self._handlers[self.BOTTOM_GROUP][STATUS_COMMAND] = self._handlers[
+            STATUS_COMMAND
+        ]
 
     def _subscribe_to_handelers_and_managers(self):
         super()._subscribe_to_handelers_and_managers()
@@ -485,19 +639,36 @@ class SwitchedLightingControl_OnOffOutlet(SwitchedLightingControl_ApplianceLinc)
         self._handlers[self.TOP_GROUP][STATUS_COMMAND].subscribe(
             self._handle_top_status
         )
-        self._handlers[self.TOP_GROUP][STATUS_COMMAND].subscribe(
-            self._handle_bottom_status
-        )
 
-    def _handle_status(self, db_version, status):
-        """Set the status of the top and bottom outlets state."""
-        self._groups[self.TOP_GROUP].value = status & 0x01
-        self._groups[self.BOTTOM_GROUP].value = status & 0x02
+        self._handlers[STATUS_COMMAND].subscribe(self._handle_status)
 
     def _handle_top_status(self, db_version, status):
         """Set the status of the top outlet."""
         self._groups[self.TOP_GROUP].value = status
 
-    def _handle_bottom_status(self, db_version, status):
-        """Set the status of the bottom outlet."""
-        self._groups[self.BOTTOM_GROUP].value = status
+    def _handle_status(self, db_version, status):
+        """Set the status of the top and bottom outlets."""
+        self._groups[self.TOP_GROUP].value = 1 if (status & 0x01) else 0
+        self._groups[self.BOTTOM_GROUP].value = 1 if (status & 0x02) else 0
+
+
+# pylint: disable=too-many-ancestors
+class SwitchedLightingControl_I3Outlet(I3Base, SwitchedLightingControl_OnOffOutlet):
+    """I3 Outlet device."""
+
+    def _register_op_flags_and_props(self):
+        self._add_operating_flag(
+            LOAD_SENSE_ON, 0, 2, 4, 5, prop_type=PropertyType.ADVANCED
+        )
+        self._add_operating_flag(
+            LOAD_SENSE_2_ON, 0, 3, 6, 7, prop_type=PropertyType.ADVANCED
+        )
+        self._register_default_op_flags_and_props(
+            dimmable=False,
+            ops_flags_1={2: LOAD_SENSE_ON, 3: LOAD_SENSE_2_ON},
+            ops_flags_2={},
+            ops_flags_3={},
+        )
+        self._operating_flags[RED_LED_OFF].property_type = PropertyType.HIDDEN
+        self._operating_flags[GREEN_LED_OFF].property_type = PropertyType.HIDDEN
+        self._operating_flags[BLUE_LED_OFF].property_type = PropertyType.HIDDEN
