@@ -9,6 +9,7 @@ ON_OFF_OUTLET_BOTTOM = "on_off_outlet_bottom"
 LOW_BATTERY = "low_battery"
 OPEN_CLOSE_SENSOR = "open_close_sensor"
 LIGHT_SENSOR = "light_sensor"
+LOAD_SENSOR = "load_sensor"
 LEAK_SENSOR_DRY = "leak_sensor_dry"
 LEAK_SENSOR_WET = "leak_sensor_wet"
 DOOR_SENSOR = "door_sensor"
@@ -33,22 +34,14 @@ HEATING = "heating"
 HUMIDIFYING = "humidifying"
 DEHUMIDIFYING = "dehumidifying"
 
-ON_OFF_SWITCH_MAIN = "{}_{}".format(ON_OFF_SWITCH, "main")
-ON_OFF_SWITCH_A = "{}_{}".format(ON_OFF_SWITCH, "a")
-ON_OFF_SWITCH_B = "{}_{}".format(ON_OFF_SWITCH, "b")
-ON_OFF_SWITCH_C = "{}_{}".format(ON_OFF_SWITCH, "c")
-ON_OFF_SWITCH_D = "{}_{}".format(ON_OFF_SWITCH, "d")
-ON_OFF_SWITCH_E = "{}_{}".format(ON_OFF_SWITCH, "e")
-ON_OFF_SWITCH_F = "{}_{}".format(ON_OFF_SWITCH, "f")
-ON_OFF_SWITCH_G = "{}_{}".format(ON_OFF_SWITCH, "g")
-ON_OFF_SWITCH_H = "{}_{}".format(ON_OFF_SWITCH, "h")
+ON_OFF_SWITCH_MAIN = f"{ON_OFF_SWITCH}_main"
+ON_OFF_SWITCH_A = f"{ON_OFF_SWITCH}_a"
+ON_OFF_SWITCH_B = f"{ON_OFF_SWITCH}_b"
+ON_OFF_SWITCH_C = f"{ON_OFF_SWITCH}_c"
+ON_OFF_SWITCH_D = f"{ON_OFF_SWITCH}_d"
+ON_OFF_SWITCH_E = f"{ON_OFF_SWITCH}_e"
+ON_OFF_SWITCH_F = f"{ON_OFF_SWITCH}_f"
+ON_OFF_SWITCH_G = f"{ON_OFF_SWITCH}_g"
+ON_OFF_SWITCH_H = f"{ON_OFF_SWITCH}_h"
 
-DIMMABLE_LIGHT_MAIN = "{}_{}".format(DIMMABLE_LIGHT, "main")
-# DIMMABLE_LIGHT_A = '{}_{}'.format(DIMMABLE_LIGHT, 'a')
-# DIMMABLE_LIGHT_B = '{}_{}'.format(DIMMABLE_LIGHT, 'b')
-# DIMMABLE_LIGHT_C = '{}_{}'.format(DIMMABLE_LIGHT, 'c')
-# DIMMABLE_LIGHT_D = '{}_{}'.format(DIMMABLE_LIGHT, 'd')
-# DIMMABLE_LIGHT_E = '{}_{}'.format(DIMMABLE_LIGHT, 'e')
-# DIMMABLE_LIGHT_F = '{}_{}'.format(DIMMABLE_LIGHT, 'f')
-# DIMMABLE_LIGHT_G = '{}_{}'.format(DIMMABLE_LIGHT, 'g')
-# DIMMABLE_LIGHT_H = '{}_{}'.format(DIMMABLE_LIGHT, 'h')
+DIMMABLE_LIGHT_MAIN = f"{DIMMABLE_LIGHT}_main"
