@@ -2,10 +2,10 @@
 
 import logging
 
-from . import inbound_handler
 from ..address import Address
 from ..constants import AllLinkMode
 from ..topics import ALL_LINKING_COMPLETED
+from . import inbound_handler
 from .inbound_base import InboundHandlerBase
 
 _LOGGER = logging.getLogger(__name__)
@@ -21,7 +21,7 @@ class AllLinkCompletedHandler(InboundHandlerBase):
     @inbound_handler
     def handle_response(
         self,
-        mode: AllLinkMode,
+        link_mode: AllLinkMode,
         group: int,
         target: Address,
         cat: int,
@@ -30,7 +30,7 @@ class AllLinkCompletedHandler(InboundHandlerBase):
     ):
         """Recieve an all link record."""
         self._call_subscribers(
-            mode=mode,
+            link_mode=link_mode,
             group=group,
             target=target,
             cat=cat,
