@@ -1,5 +1,4 @@
 """Assign a device to an all link group."""
-from .. import broadcast_handler
 from ...address import Address
 from ...topics import DELETE_FROM_ALL_LINK_GROUP
 from .broadcast_command import BroadcastCommandHandlerBase
@@ -10,11 +9,9 @@ class DeleteFromAllLinkGroupCommand(BroadcastCommandHandlerBase):
 
     def __init__(self, address: Address):
         """Init the DeleteFromAllLinkGroupCommand class."""
-        self._address = Address(address)
-        super().__init__(topic=DELETE_FROM_ALL_LINK_GROUP, address=self._address)
+        super().__init__(topic=DELETE_FROM_ALL_LINK_GROUP, address=address)
 
-    @broadcast_handler
-    def receive_id(self, cmd1, cmd2, target, user_data, hops_left):
+    def _handle_message_received(self, cmd1, cmd2, target, user_data, hops_left):
         """Receive the device ID information."""
         cat = target.high
         subcat = target.middle
@@ -25,5 +22,5 @@ class DeleteFromAllLinkGroupCommand(BroadcastCommandHandlerBase):
             subcat=subcat,
             firmware=firmware,
             group=cmd2,
-            mode=None,
+            link_mode=None,
         )
