@@ -1,6 +1,4 @@
 """Manage inbound ON command from device."""
-from .. import broadcast_handler
-from ...address import Address
 from ...topics import STOP_MANUAL_CHANGE
 from .broadcast_command import BroadcastCommandHandlerBase
 
@@ -10,13 +8,8 @@ class ManualChangeInbound(BroadcastCommandHandlerBase):
 
     def __init__(self, address, group):
         """Init the OffInbound class."""
-        self._address = Address(address)
-        self._group = group
-        super().__init__(
-            topic=STOP_MANUAL_CHANGE, address=self._address, group=self._group
-        )
+        super().__init__(topic=STOP_MANUAL_CHANGE, address=address, group=group)
 
-    @broadcast_handler
-    def handle_command(self, cmd1, cmd2, target, user_data, hops_left):
+    def _handle_message_received(self, cmd1, cmd2, target, user_data, hops_left):
         """Handle the OFF command from a device."""
         self._call_subscribers()
