@@ -1,7 +1,5 @@
 """Manage outbound ON command to a device."""
 
-from .. import broadcast_handler
-from ...address import Address
 from ...topics import ON
 from .broadcast_command import BroadcastCommandHandlerBase
 
@@ -11,11 +9,8 @@ class OnLevelInbound(BroadcastCommandHandlerBase):
 
     def __init__(self, address, group):
         """Init the OnLevelInbound class."""
-        self._address = Address(address)
-        self._group = group
-        super().__init__(topic=ON, address=self._address, group=self._group)
+        super().__init__(topic=ON, address=address, group=group)
 
-    @broadcast_handler
-    def handle_command(self, cmd1, cmd2, target, user_data, hops_left):
+    def _handle_message_received(self, cmd1, cmd2, target, user_data, hops_left):
         """Handle the ON command from a device."""
         self._call_subscribers(on_level=cmd2 if cmd2 else 0xFF)
