@@ -1,11 +1,9 @@
 """Manage inbound ON command from device."""
 import logging
 
-from .. import inbound_handler
-from ...address import Address
 from ...constants import MessageFlagType
 from ...topics import THERMOSTAT_TEMPERATURE_STATUS
-from ...utils import build_topic
+from .. import inbound_handler
 from ..inbound_base import InboundHandlerBase
 
 _LOGGER = logging.getLogger(__name__)
@@ -16,15 +14,9 @@ class ThermostatTemperatureHandler(InboundHandlerBase):
 
     def __init__(self, address):
         """Init the ThermostatTemperatureHandler class."""
-        self._address = Address(address)
         super().__init__(
             topic=THERMOSTAT_TEMPERATURE_STATUS,
-            address=self._address,
-            message_type=MessageFlagType.DIRECT,
-        )
-        self._subscriber_topic = build_topic(
-            prefix="handler.{}".format(self._address.id),  # Force address
-            topic=THERMOSTAT_TEMPERATURE_STATUS,
+            address=address,
             message_type=MessageFlagType.DIRECT,
         )
 
