@@ -1,7 +1,7 @@
 """Modem command to get the IM configuration."""
 import logging
 
-from . import ack_handler
+from . import ack_handler, nak_handler
 from ..topics import GET_IM_CONFIGURATION
 from .outbound_base import OutboundHandlerBase
 
@@ -15,13 +15,20 @@ class GetImConfigurationHandler(OutboundHandlerBase):
         """Init the GetImConfigurationHandler class."""
         super().__init__(topic=GET_IM_CONFIGURATION)
 
-    @ack_handler()
-    def handle_ack(self, disable_auto_linking, monitor_mode, auto_led, deadman):
-        """Receive the ACK message and return True."""
-
+    @ack_handler
+    async def async_handle_ack(
+        self, disable_auto_linking, monitor_mode, auto_led, deadman
+    ):
+        """Handle the ACK message from the modem."""
+        await self._async_handle_ack()
         self._call_subscribers(
             disable_auto_linking=disable_auto_linking,
             monitor_mode=monitor_mode,
             auto_led=auto_led,
             deadman=deadman,
         )
+
+    @nak_handler
+    async def async_handle_nak(self):
+        """Handle the NAK response from the modem."""
+        await self._async_handle_nak()
