@@ -2,6 +2,7 @@
 import logging
 
 from . import ack_handler, nak_handler
+from ..constants import ResponseStatus
 from ..topics import GET_NEXT_ALL_LINK_RECORD
 from .outbound_base import OutboundHandlerBase
 
@@ -15,10 +16,12 @@ class GetNextAllLinkRecordHandler(OutboundHandlerBase):
         """Init the GetNextAldbRecordNak class."""
         super().__init__(topic=GET_NEXT_ALL_LINK_RECORD)
 
-    @ack_handler()
-    def handle_ack(self):
-        """Handle the ACK message and return True."""
+    @ack_handler
+    async def async_handle_ack(self):
+        """Handle the ACK response from the modem."""
+        return await self._async_handle_ack()
 
     @nak_handler
-    def handle_nak(self):
-        """Receive the NAK message and return False."""
+    async def async_handle_nak(self):
+        """Handle the NAK response from the modem."""
+        await self._message_response.put(ResponseStatus.FAILURE)
