@@ -1,5 +1,5 @@
 """Send a Start All-Linking command."""
-from . import ack_handler
+from . import ack_handler, nak_handler
 from ..topics import SEND_ALL_LINK_COMMAND
 from .outbound_base import OutboundHandlerBase
 
@@ -16,6 +16,12 @@ class SendAllLinkCommandHandler(OutboundHandlerBase):
         """Send the Start All-Linking message asyncronously."""
         return await super().async_send(group=group, cmd1=cmd1, cmd2=cmd2)
 
-    @ack_handler(wait_response=False)
-    def handle_ack(self, group, cmd1, cmd2):
-        """Handle the message ACK returning True to the async_send method."""
+    @ack_handler
+    async def async_handle_ack(self, group, cmd1, cmd2):
+        """Handle the ACK response."""
+        await self._async_handle_ack()
+
+    @nak_handler
+    async def async_handle_nak(self, group, cmd1, cmd2):
+        """Handle the NAK response."""
+        await self._async_handle_nak()
