@@ -7,3 +7,8 @@ All-Link database.
 Direct commands are sent to the device to trigger an All-Link group and/or
 a state change on the device.
 """
+
+# pylint: disable=unused-import
+from .peek import PeekCommand  # noqa: F401
+from .poke import PokeCommand  # noqa: F401
+from .set_msb import SetMsbCommand  # noqa: F401
