@@ -1,5 +1,5 @@
 """Manage outbound ON command to a device."""
-from .. import direct_ack_handler
+
 from ...topics import OFF
 from .direct_command import DirectCommandHandlerBase
 
@@ -16,7 +16,8 @@ class OffCommand(DirectCommandHandlerBase):
         """Send the OFF command async."""
         return await super().async_send(group=self._group)
 
-    @direct_ack_handler
-    def handle_direct_ack(self, cmd1, cmd2, target, user_data, hops_left):
-        """Handle the OFF response direct ACK."""
+    def _update_subscribers_on_direct_ack(
+        self, cmd1, cmd2, target, user_data, hops_left
+    ):
+        """Update subscribers."""
         self._call_subscribers(on_level=0)
