@@ -1,5 +1,4 @@
 """Manage outbound ON command to a device."""
-from .. import direct_ack_handler
 from ...topics import PRODUCT_DATA_REQUEST
 from .direct_command import DirectCommandHandlerBase
 
@@ -16,9 +15,10 @@ class ProductDataRequestCommand(DirectCommandHandlerBase):
         """Send the OFF command async."""
         return await super().async_send()
 
-    @direct_ack_handler
-    def handle_direct_ack(self, cmd1, cmd2, target, user_data, hops_left):
-        """Handle the OFF response direct ACK."""
+    def _update_subscribers_on_direct_ack(
+        self, cmd1, cmd2, target, user_data, hops_left
+    ):
+        """Update subscribers."""
         if user_data is None:
             return
         product_bytes = bytearray([user_data["d2"], user_data["d3"], user_data["d4"]])
