@@ -1,7 +1,6 @@
 """Handle sending a read request for ALDB records."""
 import logging
 
-from .. import direct_ack_handler, direct_nak_handler
 from ...address import Address
 from ...topics import EXTENDED_READ_WRITE_ALDB
 from .direct_command import DirectCommandHandlerBase
@@ -16,11 +15,6 @@ class ReadALDBCommandHandler(DirectCommandHandlerBase):
         """Init the ReadALDBCommandHandler."""
         super().__init__(topic=EXTENDED_READ_WRITE_ALDB, address=address)
 
-    # pylint: disable=arguments-differ
-    def send(self, mem_addr: int = 0x0000, num_recs: int = 0):
-        """Send ALDB read message."""
-        super().send(mem_addr=mem_addr, num_recs=num_recs)
-
     # pylint: disable=arguments-differ
     async def async_send(self, mem_addr: int = 0x0000, num_recs: int = 0):
         """Send ALDB read message asyncronously."""
@@ -28,12 +22,18 @@ class ReadALDBCommandHandler(DirectCommandHandlerBase):
             action=0x00, mem_addr=mem_addr, num_recs=num_recs
         )
 
-    @direct_ack_handler
-    def handle_direct_ack(self, cmd1, cmd2, target, user_data, hops_left):
-        """Handle the direct ACK."""
-        self._call_subscribers(ack_response=cmd2)
+    def _update_subscribers_on_direct_ack(
+        self, cmd1, cmd2, target, user_data, hops_left
+    ):
+        """Update subscribers."""
+        self._call_subscribers(response=0)
 
-    @direct_nak_handler
-    def handle_direct_nak(self, cmd1, cmd2, target, user_data, hops_left):
-        """Handle a direct NAK which will provide an error message."""
-        self._call_subscribers(ack_response=cmd2)
+    def _update_subscribers_on_nak(self, cmd1, cmd2, target, user_data, hops_left):
+        """Update subscribers on DIIRECT NAK received."""
+        self._call_subscribers(response=cmd2)
+
+    def _update_subscribers_on_direct_nak(
+        self, cmd1, cmd2, target, user_data, hops_left
+    ):
+        """Update subscribers on DIIRECT NAK received."""
+        self._call_subscribers(response=cmd2)
