@@ -1,5 +1,5 @@
 """KeypadLinc command handler to trigger a button scene."""
-from .. import ack_handler, direct_ack_handler
+from .. import ack_handler
 from ...topics import EXTENDED_TRIGGER_ALL_LINK
 from ..to_device.direct_command import DirectCommandHandlerBase
 
@@ -15,29 +15,20 @@ class TriggerSceneOffCommandHandler(DirectCommandHandlerBase):
     # pylint: disable=arguments-differ
     async def async_send(self, fast: bool = False):
         """Set the LED values of the KPL."""
-        ramp_rate = 1 if fast else 0
-        kwargs = {
-            "data1": self._group,
-            "data2": 1,
-            "data3": 0,
-            "data4": 0x13,
-            "data5": 0,
-            "data6": ramp_rate,
-        }
+        return await super().async_send(group=self._group, on_level=0, fast=fast)
 
-        return await super().async_send(**kwargs)
-
-    @ack_handler(wait_response=True)
-    def handle_ack(self, cmd1, cmd2, user_data):
+    @ack_handler
+    async def async_handle_ack(self, cmd1, cmd2, user_data):
         """Handle the ACK response.
 
         Required since the BEEP command uses the same cmd1, cmd2 values.
         """
-        if not user_data and not user_data["data1"] == self._group:
+        if not user_data and not user_data["d1"] == self._group:
             return
-        return super().handle_ack(cmd1, cmd2, user_data)
+        return await super().async_handle_ack(cmd1=cmd1, cmd2=cmd2, user_data=user_data)
 
-    @direct_ack_handler
-    def handle_direct_ack(self, cmd1, cmd2, target, user_data, hops_left):
-        """Handle the direct ACK message."""
+    def _update_subscribers_on_direct_ack(
+        self, cmd1, cmd2, target, user_data, hops_left
+    ):
+        """Update subscribers."""
         self._call_subscribers(on_level=0)
