@@ -5,17 +5,17 @@ This is used by the stdout log so that it does not echo the command but the comm
 from logging import Filter
 
 
-class CommandFilter(Filter):
-    """Filter out command logging."""
+class NoStdoutFilter(Filter):
+    """Filter output to standard out."""
 
-    def __init__(self, prompt):
+    def __init__(self, prefix):
         """Init the CommandFilter class."""
-        super(CommandFilter, self).__init__()
-        self.prompt = prompt
+        super().__init__()
+        self.prefix = prefix
 
     def filter(self, record):
         """Filter out commands."""
-        if record.msg[0 : len(self.prompt)] == self.prompt:
+        if record.msg[0 : len(self.prefix)] == self.prefix:
             return False
         return True
 
@@ -25,11 +25,13 @@ class StdoutFilter(Filter):
 
     def __init__(self, prefix):
         """Init the CommandFilter class."""
-        super(StdoutFilter, self).__init__()
+        super().__init__()
         self.prefix = prefix
 
     def filter(self, record):
         """Filter out commands."""
+        if record.msg.find("Encoding detection") != -1:
+            return False
         if record.msg[0 : len(self.prefix)] == self.prefix:
             record.msg = self.strip_prefix(record.msg)
             return True
@@ -38,3 +40,24 @@ class StdoutFilter(Filter):
     def strip_prefix(self, msg):
         """Strip the prefix from the log message before writing out."""
         return msg[len(self.prefix) :]
+
+
+class StripPrefixFilter(Filter):
+    """Allow output to standard out but strip prefix if it is present."""
+
+    def __init__(self, prefix):
+        """Init the CommandFilter class."""
+        super().__init__()
+        self.prefix = prefix
+
+    def filter(self, record):
+        """Filter out commands."""
+        if record.msg.find("Encoding detection") != -1:
+            return False
+        if record.msg[0 : len(self.prefix)] == self.prefix:
+            record.msg = self.strip_prefix(record.msg)
+        return True
+
+    def strip_prefix(self, msg):
+        """Strip the prefix from the log message before writing out."""
+        return msg[len(self.prefix) :]
